@@ -9,6 +9,7 @@ from discord import AutoShardedBot, Embed, Colour, PermissionOverwrite, Permissi
 from discord.ui import Button
 from discord.abc import PrivateChannel
 
+from .errors import *
 from .._DshellParser.ast_nodes import *
 from ..DISCORD_COMMANDS.utils.utils_permissions import DshellPermissions
 from .._DshellParser.dshell_parser import parse
@@ -28,13 +29,19 @@ class DshellInterpreteur:
     Make what you want with Dshell code to interact with Discord !
     """
 
-    def __init__(self, code: str, ctx: context, debug: bool = False, vars: Optional[str] = None):
+    def __init__(self, code: str, ctx: context,
+                 debug: bool = False,
+                 vars: Optional[str] = None,
+                 vars_env: Optional[dict[str, Any]] = None):
         """
         Interpreter Dshell code
         :param code: The code to interpret. Each line must end with a newline character, except SEPARATOR and SUB_SEPARATOR tokens.
         :param ctx: The context in which the code is executed. It can be a Discord bot, a message, or a channel.
-        :param debug: If True, prints the AST of the code.
+        :param debug: If True, prints the AST of the code and put the ctx to None.
         :param vars: Optional dictionary of variables to initialize in the interpreter's environment.
+        :param vars_env: Optional dictionary of additional environment variables to add to the interpreter's environment.
+
+        Note: __message_before__ (message content before edit) can be overwritten by vars_env parameter.
         """
         self.ast: list[ASTNode] = parse(DshellTokenizer(code).start(), StartNode([]))[0]
         message = ctx.message if isinstance(ctx, Interaction) else ctx
@@ -50,6 +57,8 @@ class DshellInterpreteur:
             '__author_id__': message.author.id,
 
             '__message__': message.content,
+            '__message_author__': message.author.id,
+            '__message_before__': message.content,  # same as __message__, but before edit. Can be overwritten by add vars_env parameter
             '__message_content__': message.content,
             '__message_id__': message.id,
             '__message_url__': message.jump_url if hasattr(message, 'jump_url') else None,
@@ -81,6 +90,8 @@ class DshellInterpreteur:
             '__guild_channels_count__': len(message.channel.guild.channels),
 
         } if message is not None and not debug else {} # {} is used in debug mode, when ctx is None
+        if vars_env is not None: # add the variables to the environment
+            self.env.update(vars_env)
         self.vars = vars if vars is not None else ''
         self.ctx: context = ctx
         if debug:
@@ -184,7 +195,10 @@ class DshellInterpreteur:
 
 
             elif isinstance(node, EndNode):
-                raise RuntimeError("Execution stopped - EndNode encountered")
+                if self.eval_data_token(node.error_message):
+                    raise RuntimeError("Execution stopped - EndNode encountered")
+                else:
+                    raise DshellInterpreterStopExecution()
 
     def eval_data_token(self, token: Token):
         """
